==> slashdb-1.5.36-cp36-cp36m-manylinux2014_x86_64.whl: slashdb/auth/__init__.py <==
import functools
import logging
from importlib import import_module

import pyramid_beaker
from pyramid_multiauth import MultiAuthenticationPolicy

log = logging.getLogger('slashdb_auth')


class ConfigMultiAuthenticationPolicy(MultiAuthenticationPolicy):
    def __init__(self, ini_settings, callback=None):
        auth_settings = ini_settings['auth_settings']
        policies = []
        policy_configs = auth_settings.get('authentication_policies').items()
        # only enabled
        policy_configs = filter(
            lambda policy: policy[1]['enabled'],
            policy_configs
        )
        # sort by priority
        policy_configs = sorted(
            policy_configs,
            key=lambda policy: policy[1]['priority']
        )
        for name, cfg in policy_configs:
            if cfg['enabled']:
                try:
                    module_name = f'slashdb.auth.{name}'
                    module = import_module(module_name)
                    policies.append(module.policy(ini_settings))
                except ModuleNotFoundError as exc:
                    log.info(f'Authentication policy named "{name} not found.')
                    log.debug(exc)

        super(ConfigMultiAuthenticationPolicy, self).__init__(policies,
                                                              callback)


class BaseAuthenticationPolicy:
    def __init__(self, ini_settings, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.ini_settings = ini_settings
        self.sdb_settings = ini_settings['sdb_settings']
        self.auth_settings = self.ini_settings['auth_settings']
        self.users = self.sdb_settings['config_storage'].users


def auto_secure_cookie_wrapper(ini_settings: dict):
    """Set cookie secure flag depending on http or https for pyramid-beaker

    Wrapped to modify session class.
    Done this way, because original class is defined at runtime, as local
    variable. And it is not possible to modify it before.
    # 617

    :param ini_settings: Pyramid INI file settings.
    """

    policies = ini_settings['auth_settings']['authentication_policies']
    try:
        cookie_enabled = policies['cookie']['enabled']
    except (AttributeError, KeyError):
        return None

    if not cookie_enabled:
        return None

    original_class = pyramid_beaker.session_factory_from_settings(ini_settings)
    secure = ini_settings['cookie_secure']
    if secure != 'auto':
        return original_class

    # Make copy of original __init__, so we can call it without recursion
    orig_init = original_class.__init__

    # Wrap original init to preserve func metadata
    @functools.wraps(orig_init)
    def __init__(self, request, *args, **kws):
        # secure flag for https requests
        self._options['secure'] = request.scheme == 'https'

        # Call the original __init__
        orig_init(self, request, *args, **kws)

    # update init
    original_class.__init__ = __init__

    return original_class

==> slashdb-1.6.43-cp36-cp36m-manylinux2014_x86_64.whl: slashdb/auth/__init__.py <==
import functools
import logging
from importlib import import_module

import pyramid_beaker
from pyramid_multiauth import MultiAuthenticationPolicy

log = logging.getLogger('slashdb.auth')


class ConfigMultiAuthenticationPolicy(MultiAuthenticationPolicy):
    def __init__(self, ini_settings, callback=None):
        auth_settings = ini_settings['auth_settings']
        policies = []
        policy_configs = auth_settings.get('authentication_policies').items()
        # only enabled
        policy_configs = filter(
            lambda policy: policy[1]['enabled'],
            policy_configs
        )
        # sort by priority
        policy_configs = sorted(
            policy_configs,
            key=lambda policy: policy[1]['priority']
        )
        for name, cfg in policy_configs:
            if name == 'saml':
                # saml is not implemented as a policy
                continue
                
            if cfg['enabled']:
                try:
                    module_name = f'slashdb.auth.{name}'
                    module = import_module(module_name)
                    policies.append(module.policy(ini_settings))
                except ModuleNotFoundError as exc:
                    log.info(f'Authentication policy named "{name} not found.')
                    log.debug(exc)

        super(ConfigMultiAuthenticationPolicy, self).__init__(policies,
                                                              callback)


class BaseAuthenticationPolicy:
    def __init__(self, ini_settings, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.ini_settings = ini_settings
        self.sdb_settings = ini_settings['sdb_settings']
        self.auth_settings = self.ini_settings['auth_settings']
        self.users = self.sdb_settings['config_storage'].users


def auto_secure_cookie_wrapper(ini_settings: dict):
    """Set cookie secure flag depending on http or https for pyramid-beaker

    Wrapped to modify session class.
    Done this way, because original class is defined at runtime, as local
    variable. And it is not possible to modify it before.
    # 617

    :param ini_settings: Pyramid INI file settings.
    """

    policies = ini_settings['auth_settings']['authentication_policies']
    try:
        cookie_enabled = policies['cookie']['enabled']
    except (AttributeError, KeyError):
        return None

    if not cookie_enabled:
        return None

    original_class = pyramid_beaker.session_factory_from_settings(ini_settings)
    secure = ini_settings['cookie_secure']
    if secure != 'auto':
        return original_class

    # Make copy of original __init__, so we can call it without recursion
    orig_init = original_class.__init__

    # Wrap original init to preserve func metadata
    @functools.wraps(orig_init)
    def __init__(self, request, *args, **kws):
        # secure flag for https requests
        self._options['secure'] = request.scheme == 'https'

        # Call the original __init__
        orig_init(self, request, *args, **kws)

    # update init
    original_class.__init__ = __init__

    return original_class
